==> fred_regal-1.0.1-py3-none-any.whl: regal/tests/test_nsset.py <==
from ipaddress import IPv4Address
from typing import Optional
from unittest import IsolatedAsyncioTestCase
from unittest.mock import call, sentinel

from fred_api.registry.nsset.nsset_history_types_pb2 import NssetHistoryRecord, NssetHistoryReply, NssetHistoryRequest
from fred_api.registry.nsset.nsset_info_types_pb2 import (
    CheckDnsHostReply,
    CheckDnsHostRequest,
    DnsHost as DnsHostMessage,
    NssetIdReply,
    NssetIdRequest,
    NssetInfoReply,
    NssetInfoRequest,
)
from fred_api.registry.nsset.nsset_state_history_types_pb2 import (
    NssetStateHistory,
    NssetStateHistoryReply,
    NssetStateHistoryRequest,
)
from fred_api.registry.nsset.nsset_state_types_pb2 import NssetStateReply, NssetStateRequest
from frgal.utils import AsyncTestClientMixin, make_awaitable

from regal.nsset import DnsHost, Nsset, NssetClient, NssetHistoryId, NssetId
from regal.tests.common import ObjectClientTestMixin


class TestNssetClient(AsyncTestClientMixin, NssetClient):
    """Test NssetClient."""


class NssetClientTest(ObjectClientTestMixin[TestNssetClient], IsolatedAsyncioTestCase):
    """Test NssetClient's methods."""

    grpc_namespace = "/Fred.Registry.Api.Nsset.Nsset"
    get_state_request = NssetStateRequest
    get_state_reply = NssetStateReply
    get_state_method = "get_nsset_state"
    get_history_request = NssetHistoryRequest
    get_history_reply = NssetHistoryReply
    get_history_method = "get_nsset_history"
    get_history_record = NssetHistoryRecord
    get_state_history_request = NssetStateHistoryRequest
    get_state_history_reply = NssetStateHistoryReply
    get_state_history_method = "get_nsset_state_history"
    get_state_history_record = NssetStateHistory.Record

    def setUp(self):
        self.client = TestNssetClient(netloc=sentinel.netloc)

    async def test_get_nsset_id(self):
        nsset_id = NssetId("kryten")
        reply = NssetIdReply()
        reply.data.nsset_id.uuid.value = str(nsset_id)
        self.client.mock.return_value = make_awaitable(reply)

        response = await self.client.get_nsset_id("HANDLE")
        self.assertEqual(response, nsset_id)
        self.assertIsInstance(response, NssetId)

        request = NssetIdRequest()
        request.nsset_handle.value = "HANDLE"
        self.client.mock.assert_called_once_with(
            request,
            method="/Fred.Registry.Api.Nsset.Nsset/get_nsset_id",
            timeout=None,
        )

    async def _test_get_nsset_info(self, nsset_history_id: Optional[NssetHistoryId] = None) -> None:
        dns_host = DnsHostMessage()
        dns_host.fqdn = "dns.example.com"
        dns_host.ip_addresses[:] = ["127.0.0.1"]
        reply = NssetInfoReply()
        reply.data.nsset_id.uuid.value = "kryten"
        if nsset_history_id:
            reply.data.nsset_history_id.uuid.value = nsset_history_id
        reply.data.nsset_handle.value = "HANDLE"
        reply.data.dns_hosts.extend([dns_host])
        self.client.mock.return_value = make_awaitable(reply)

        response = await self.client.get_nsset_info(NssetId("kryten"), history_id=nsset_history_id)

        self.assertEqual(
            response,
            Nsset(
                nsset_id=NssetId("kryten"),
                nsset_history_id=nsset_history_id,
                nsset_handle="HANDLE",
                dns_hosts=[DnsHost(fqdn="dns.example.com", ip_addresses=[IPv4Address("127.0.0.1")])],
            ),
        )

        request = NssetInfoRequest()
        request.nsset_id.uuid.value = "kryten"
        if nsset_history_id:
            request.nsset_history_id.uuid.value = nsset_history_id
        self.client.mock.assert_called_once_with(
            request,
            method="/Fred.Registry.Api.Nsset.Nsset/get_nsset_info",
            timeout=None,
        )

    async def test_get_nsset_info(self):
        await self._test_get_nsset_info()

    async def test_get_nsset_info_with_history_id(self):
        await self._test_get_nsset_info(nsset_history_id="nova-5")

    async def test_check_dns_host(self):
        reply = CheckDnsHostReply()
        reply.data.dns_host_exists = True
        self.client.mock.return_value = make_awaitable(reply)

        self.assertTrue(await self.client.check_dns_host("ns.example.org"))

        request = CheckDnsHostRequest()
        request.fqdn = "ns.example.org"
        self.assertEqual(
            self.client.mock.mock_calls,
            [call(request, method="/Fred.Registry.Api.Nsset.Nsset/check_dns_host", timeout=None)],
        )

==> fred_regal-1.1.2-py3-none-any.whl: regal/tests/test_nsset.py <==
from ipaddress import IPv4Address
from typing import Optional
from unittest import IsolatedAsyncioTestCase
from unittest.mock import call, sentinel

from fred_api.registry.nsset.nsset_history_types_pb2 import NssetHistoryRecord, NssetHistoryReply, NssetHistoryRequest
from fred_api.registry.nsset.nsset_info_types_pb2 import (
    CheckDnsHostReply,
    CheckDnsHostRequest,
    DnsHost as DnsHostMessage,
    NssetIdReply,
    NssetIdRequest,
    NssetInfoReply,
    NssetInfoRequest,
)
from fred_api.registry.nsset.nsset_state_history_types_pb2 import (
    NssetStateHistory,
    NssetStateHistoryReply,
    NssetStateHistoryRequest,
)
from fred_api.registry.nsset.nsset_state_types_pb2 import NssetStateReply, NssetStateRequest
from frgal.utils import AsyncTestClientMixin, make_awaitable

from regal.nsset import DnsHost, Nsset, NssetClient, NssetHistoryId, NssetId
from regal.tests.common import ObjectClientTestMixin


class TestNssetClient(AsyncTestClientMixin, NssetClient):
    """Test NssetClient."""


class NssetClientTest(ObjectClientTestMixin[TestNssetClient], IsolatedAsyncioTestCase):
    """Test NssetClient's methods."""

    grpc_namespace = "/Fred.Registry.Api.Nsset.Nsset"
    get_state_request = NssetStateRequest
    get_state_reply = NssetStateReply
    get_state_method = "get_nsset_state"
    get_history_request = NssetHistoryRequest
    get_history_reply = NssetHistoryReply
    get_history_method = "get_nsset_history"
    get_history_record = NssetHistoryRecord
    get_state_history_request = NssetStateHistoryRequest
    get_state_history_reply = NssetStateHistoryReply
    get_state_history_method = "get_nsset_state_history"
    get_state_history_record = NssetStateHistory.Record

    def setUp(self):
        self.client = TestNssetClient(netloc=sentinel.netloc)

    async def test_get_nsset_id(self):
        nsset_id = NssetId("kryten")
        reply = NssetIdReply()
        reply.data.nsset_id.uuid.value = str(nsset_id)
        self.client.mock.return_value = make_awaitable(reply)

        response = await self.client.get_nsset_id("HANDLE")
        self.assertEqual(response, nsset_id)
        self.assertIsInstance(response, NssetId)

        request = NssetIdRequest()
        request.nsset_handle.value = "HANDLE"
        self.client.mock.assert_called_once_with(
            request,
            method="/Fred.Registry.Api.Nsset.Nsset/get_nsset_id",
            timeout=None,
        )

    async def _test_get_nsset_info(self, nsset_history_id: Optional[NssetHistoryId] = None) -> None:
        dns_host = DnsHostMessage()
        dns_host.fqdn = "dns.example.com"
        dns_host.ip_addresses[:] = ["127.0.0.1"]
        reply = NssetInfoReply()
        reply.data.nsset_id.uuid.value = "kryten"
        if nsset_history_id:
            reply.data.nsset_history_id.uuid.value = nsset_history_id
        reply.data.nsset_handle.value = "HANDLE"
        reply.data.dns_hosts.extend([dns_host])
        self.client.mock.return_value = make_awaitable(reply)

        response = await self.client.get_nsset_info(NssetId("kryten"), history_id=nsset_history_id)

        self.assertEqual(
            response,
            Nsset(
                nsset_id=NssetId("kryten"),
                nsset_history_id=nsset_history_id,
                nsset_handle="HANDLE",
                dns_hosts=[DnsHost(fqdn="dns.example.com", ip_addresses=[IPv4Address("127.0.0.1")])],
            ),
        )

        request = NssetInfoRequest()
        request.nsset_id.uuid.value = "kryten"
        if nsset_history_id:
            request.nsset_history_id.uuid.value = nsset_history_id
        self.client.mock.assert_called_once_with(
            request,
            method="/Fred.Registry.Api.Nsset.Nsset/get_nsset_info",
            timeout=None,
        )

    async def test_get_nsset_info(self):
        await self._test_get_nsset_info()

    async def test_get_nsset_info_with_history_id(self):
        await self._test_get_nsset_info(nsset_history_id=NssetHistoryId("nova-5"))

    async def test_check_dns_host(self):
        reply = CheckDnsHostReply()
        reply.data.dns_host_exists = True
        self.client.mock.return_value = make_awaitable(reply)

        self.assertTrue(await self.client.check_dns_host("ns.example.org"))

        request = CheckDnsHostRequest()
        request.fqdn = "ns.example.org"
        self.assertEqual(
            self.client.mock.mock_calls,
            [call(request, method="/Fred.Registry.Api.Nsset.Nsset/check_dns_host", timeout=None)],
        )
